package com.cardiff.client_project.service.impl;

import com.cardiff.client_project.mapper.HospitalMapper;
import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.service.HospitalService;
import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class HospitalServiceImpl implements HospitalService {

    @Autowired
    private HospitalMapper hospitalMapper;

    @Override
    public Result getAvailableBeds(String name) {
        try {
            List<HospitalDTO> hospitals = hospitalMapper.findAvailableBeds(name);
            if (hospitals.isEmpty()) {
                return Result.error("No hospitals with available beds found.");
            }
            return Result.success(hospitals);
        } catch (Exception e) {
            return Result.error("Error fetching available beds: " + e.getMessage());
        }
    }

    @Override
    public Result insertHospitalInfo(HospitalDTO hospitalDTO) {
        try {
            int result = hospitalMapper.insertHospital(hospitalDTO);
            if (result > 0) {
                return Result.success("Hospital added successfully.");
            }
            return Result.error("Failed to add hospital.");
        } catch (Exception e) {
            return Result.error("Error adding hospital: " + e.getMessage());
        }
    }

    @Override
    public Result updateHospital(HospitalDTO hospitalDTO) {
        try {
            int result = hospitalMapper.updateHospital(hospitalDTO);
            if (result > 0) {
                return Result.success("Hospital updated successfully.");
            }
            return Result.error("Failed to update hospital.");
        } catch (Exception e) {
            return Result.error("Error updating hospital: " + e.getMessage());
        }
    }

    @Override
    public Result deleteHospitalById(List<Integer> ids) {
        try {
            int[] results = hospitalMapper.deleteHospitalByIds(ids);
            if (results.length > 0) {
                return Result.success("Hospitals deleted successfully.");
            }
            return Result.error("No hospitals were deleted.");
        } catch (Exception e) {
            return Result.error("Error deleting hospitals: " + e.getMessage());
        }
    }

    @Override
    public Result getAllHospitals() {
        try {
            List<HospitalDTO> hospitals = hospitalMapper.findAllHospitals();
            return Result.success(hospitals);
        } catch (Exception e) {
            return Result.error("Error fetching hospitals: " + e.getMessage());
        }
    }

    @Override
    public Result updateBedCount(int hospitalId, int currentPatients) {
        try {
            int result = hospitalMapper.updateBedCount(hospitalId, currentPatients);
            if (result > 0) {
                return Result.success("Bed count updated successfully");
            }
            return Result.error("Failed to update bed count - check capacity limits");
        } catch (Exception e) {
            return Result.error("Error updating bed count: " + e.getMessage());
        }
    }
}